CVS commit: src/tests/lib/libc/c063

2012-11-23 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Fri Nov 23 08:24:20 UTC 2012

Modified Files:
src/tests/lib/libc/c063: t_o_search.c

Log Message:
Split the test cases where root/non-root makes a difference in two and mark
them apropriately. Exact permission semantics are still under discussion,
this will have to be cleaned up once that discussion is settled.
For now, one test cases fails.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/tests/lib/libc/c063/t_o_search.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/lib/libc/c063/t_o_search.c
diff -u src/tests/lib/libc/c063/t_o_search.c:1.1 src/tests/lib/libc/c063/t_o_search.c:1.2
--- src/tests/lib/libc/c063/t_o_search.c:1.1	Sun Nov 18 17:41:54 2012
+++ src/tests/lib/libc/c063/t_o_search.c	Fri Nov 23 08:24:20 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: t_o_search.c,v 1.1 2012/11/18 17:41:54 manu Exp $ */
+/*	$NetBSD: t_o_search.c,v 1.2 2012/11/23 08:24:20 martin Exp $ */
 
 /*-
  * Copyright (c) 2012 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include sys/cdefs.h
-__RCSID($NetBSD: t_o_search.c,v 1.1 2012/11/18 17:41:54 manu Exp $);
+__RCSID($NetBSD: t_o_search.c,v 1.2 2012/11/23 08:24:20 martin Exp $);
 
 #include atf-c.h
 #include errno.h
@@ -81,13 +81,14 @@ ATF_TC_CLEANUP(o_search_perm1, tc)
 	(void)rmdir(DIR);
 } 
 
-ATF_TC_WITH_CLEANUP(o_search_flag1);
-ATF_TC_HEAD(o_search_flag1, tc)
+ATF_TC_WITH_CLEANUP(o_search_root_flag1);
+ATF_TC_HEAD(o_search_root_flag1, tc)
 {
 	atf_tc_set_md_var(tc, descr, See that openat honours O_SEARCH);
+	atf_tc_set_md_var(tc, require.user, root);
 }
 
-ATF_TC_BODY(o_search_flag1, tc)
+ATF_TC_BODY(o_search_root_flag1, tc)
 {
 	int dfd;
 	int fd;
@@ -113,7 +114,46 @@ ATF_TC_BODY(o_search_flag1, tc)
 	ATF_REQUIRE(close(dfd) == 0);
 }
 
-ATF_TC_CLEANUP(o_search_flag1, tc)
+ATF_TC_CLEANUP(o_search_root_flag1, tc)
+{
+	(void)unlink(FILE);
+	(void)rmdir(DIR);
+} 
+
+ATF_TC_WITH_CLEANUP(o_search_unpriv_flag1);
+ATF_TC_HEAD(o_search_unpriv_flag1, tc)
+{
+	atf_tc_set_md_var(tc, descr, See that openat honours O_SEARCH);
+	atf_tc_set_md_var(tc, require.user, unprivileged);
+}
+
+ATF_TC_BODY(o_search_unpriv_flag1, tc)
+{
+	int dfd;
+	int fd;
+
+	ATF_REQUIRE(mkdir(DIR, 0755) == 0);
+	ATF_REQUIRE((fd = open(FILE, O_CREAT|O_RDWR, 0644)) != -1);
+	ATF_REQUIRE(close(fd) == 0);
+
+	ATF_REQUIRE((dfd = open(DIR, O_RDONLY|O_SEARCH, 0)) != -1);
+
+	ATF_REQUIRE((fd = openat(dfd, BASEFILE, O_RDWR, 0)) != -1);
+	ATF_REQUIRE(close(fd) == 0);
+
+	ATF_REQUIRE(fchmod(dfd, 744) == 0);
+
+	ATF_REQUIRE((fd = openat(dfd, BASEFILE, O_RDWR, 0)) != -1);
+	ATF_REQUIRE(close(fd) == 0);
+
+	ATF_REQUIRE(fchmod(dfd, 444) == 0);
+
+	ATF_REQUIRE((fd = openat(dfd, BASEFILE, O_RDWR, 0)) == -1);
+
+	ATF_REQUIRE(close(dfd) == 0);
+}
+
+ATF_TC_CLEANUP(o_search_unpriv_flag1, tc)
 {
 	(void)unlink(FILE);
 	(void)rmdir(DIR);
@@ -152,13 +192,14 @@ ATF_TC_CLEANUP(o_search_perm2, tc)
 	(void)rmdir(DIR);
 } 
 
-ATF_TC_WITH_CLEANUP(o_search_flag2);
-ATF_TC_HEAD(o_search_flag2, tc)
+ATF_TC_WITH_CLEANUP(o_search_root_flag2);
+ATF_TC_HEAD(o_search_root_flag2, tc)
 {
 	atf_tc_set_md_var(tc, descr, See that fstatat honours O_SEARCH);
+	atf_tc_set_md_var(tc, require.user, root);
 }
 
-ATF_TC_BODY(o_search_flag2, tc)
+ATF_TC_BODY(o_search_root_flag2, tc)
 {
 	int dfd;
 	int fd;
@@ -182,7 +223,44 @@ ATF_TC_BODY(o_search_flag2, tc)
 	ATF_REQUIRE(close(dfd) == 0);
 }
 
-ATF_TC_CLEANUP(o_search_flag2, tc)
+ATF_TC_CLEANUP(o_search_root_flag2, tc)
+{
+	(void)unlink(FILE);
+	(void)rmdir(DIR);
+} 
+
+ATF_TC_WITH_CLEANUP(o_search_unpriv_flag2);
+ATF_TC_HEAD(o_search_unpriv_flag2, tc)
+{
+	atf_tc_set_md_var(tc, descr, See that fstatat honours O_SEARCH);
+	atf_tc_set_md_var(tc, require.user, unprivileged);
+}
+
+ATF_TC_BODY(o_search_unpriv_flag2, tc)
+{
+	int dfd;
+	int fd;
+
+	ATF_REQUIRE(mkdir(DIR, 0755) == 0);
+	ATF_REQUIRE((fd = open(FILE, O_CREAT|O_RDWR, 0644)) != -1);
+	ATF_REQUIRE(close(fd) == 0);
+
+	ATF_REQUIRE((dfd = open(DIR, O_RDONLY|O_SEARCH, 0)) != -1);
+
+	ATF_REQUIRE(faccessat(dfd, BASEFILE, W_OK, 0) == 0);
+
+	ATF_REQUIRE(fchmod(dfd, 744) == 0);
+
+	ATF_REQUIRE(faccessat(dfd, BASEFILE, W_OK, 0) == 0);
+
+	ATF_REQUIRE(fchmod(dfd, 444) == 0);
+
+	ATF_REQUIRE(faccessat(dfd, BASEFILE, W_OK, 0) == 0);
+
+	ATF_REQUIRE(close(dfd) == 0);
+}
+
+ATF_TC_CLEANUP(o_search_unpriv_flag2, tc)
 {
 	(void)unlink(FILE);
 	(void)rmdir(DIR);
@@ -217,9 +295,11 @@ ATF_TP_ADD_TCS(tp)
 {
 
 	ATF_TP_ADD_TC(tp, o_search_perm1);
-	ATF_TP_ADD_TC(tp, o_search_flag1);
+	ATF_TP_ADD_TC(tp, o_search_root_flag1);
+	ATF_TP_ADD_TC(tp, o_search_unpriv_flag1);
 	ATF_TP_ADD_TC(tp, o_search_perm2);
-	ATF_TP_ADD_TC(tp, o_search_flag2);
+	ATF_TP_ADD_TC(tp, o_search_root_flag2);
+	ATF_TP_ADD_TC(tp, o_search_unpriv_flag2);
 	ATF_TP_ADD_TC(tp, o_search_notdir);
 
 	return atf_no_error();



CVS commit: src

2012-11-23 Thread Nicolas Joly
Module Name:src
Committed By:   njoly
Date:   Fri Nov 23 08:36:48 UTC 2012

Modified Files:
src/distrib/sets/lists/tests: mi
src/etc/mtree: NetBSD.dist.tests

Log Message:
Adjust for usr/tests/lib/libc/c063 debug entries.


To generate a diff of this commit:
cvs rdiff -u -r1.508 -r1.509 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.89 -r1.90 src/etc/mtree/NetBSD.dist.tests

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/tests/mi
diff -u src/distrib/sets/lists/tests/mi:1.508 src/distrib/sets/lists/tests/mi:1.509
--- src/distrib/sets/lists/tests/mi:1.508	Tue Nov 20 16:18:50 2012
+++ src/distrib/sets/lists/tests/mi	Fri Nov 23 08:36:48 2012
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.508 2012/11/20 16:18:50 agc Exp $
+# $NetBSD: mi,v 1.509 2012/11/23 08:36:48 njoly Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -372,6 +372,23 @@
 ./usr/libdata/debug/usr/tests/lib/libbpfjittests-lib-debug
 ./usr/libdata/debug/usr/tests/lib/libbpfjit/t_bpfjit.debug		tests-lib-debug		debug,atf,sljit
 ./usr/libdata/debug/usr/tests/lib/libc	tests-lib-debug
+./usr/libdata/debug/usr/tests/lib/libc/c063tests-lib-debug
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_faccessat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_fchmodat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_fchownat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_fexecve.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_fstatat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_linkat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_mkdirat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_mkfifoat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_mknodat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_o_search.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_openat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_readlinkat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_renameat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_symlinkat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_unlinkat.debug		tests-lib-debug		debug,atf
+./usr/libdata/debug/usr/tests/lib/libc/c063/t_utimensat.debug		tests-lib-debug		debug,atf
 ./usr/libdata/debug/usr/tests/lib/libc/dbtests-lib-debug
 ./usr/libdata/debug/usr/tests/lib/libc/db/h_db.debug			tests-lib-debug		debug,atf
 ./usr/libdata/debug/usr/tests/lib/libc/gentests-lib-debug

Index: src/etc/mtree/NetBSD.dist.tests
diff -u src/etc/mtree/NetBSD.dist.tests:1.89 src/etc/mtree/NetBSD.dist.tests:1.90
--- src/etc/mtree/NetBSD.dist.tests:1.89	Tue Nov 20 15:41:43 2012
+++ src/etc/mtree/NetBSD.dist.tests	Fri Nov 23 08:36:47 2012
@@ -1,4 +1,4 @@
-#	$NetBSD: NetBSD.dist.tests,v 1.89 2012/11/20 15:41:43 pgoyette Exp $
+#	$NetBSD: NetBSD.dist.tests,v 1.90 2012/11/23 08:36:47 njoly Exp $
 
 ./usr/libdata/debug/usr/tests
 ./usr/libdata/debug/usr/tests/atf
@@ -52,6 +52,7 @@
 ./usr/libdata/debug/usr/tests/lib/libbluetooth
 ./usr/libdata/debug/usr/tests/lib/libbpfjit
 ./usr/libdata/debug/usr/tests/lib/libc
+./usr/libdata/debug/usr/tests/lib/libc/c063
 ./usr/libdata/debug/usr/tests/lib/libc/db
 ./usr/libdata/debug/usr/tests/lib/libc/gen
 ./usr/libdata/debug/usr/tests/lib/libc/gen/posix_spawn



CVS commit: src/lib/libp2k

2012-11-23 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Fri Nov 23 14:27:14 UTC 2012

Modified Files:
src/lib/libp2k: p2k.c

Log Message:
Explicitly cast enum type.


To generate a diff of this commit:
cvs rdiff -u -r1.59 -r1.60 src/lib/libp2k/p2k.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libp2k/p2k.c
diff -u src/lib/libp2k/p2k.c:1.59 src/lib/libp2k/p2k.c:1.60
--- src/lib/libp2k/p2k.c:1.59	Sun Nov 18 19:04:22 2012
+++ src/lib/libp2k/p2k.c	Fri Nov 23 14:27:14 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: p2k.c,v 1.59 2012/11/18 19:04:22 pooka Exp $	*/
+/*	$NetBSD: p2k.c,v 1.60 2012/11/23 14:27:14 joerg Exp $	*/
 
 /*
  * Copyright (c) 2007, 2008, 2009  Antti Kantee.  All Rights Reserved.
@@ -667,7 +667,7 @@ p2k_fs_fhtonode(struct puffs_usermount *
 
 	puffs_newinfo_setcookie(pni, p2n);
 	rump_pub_getvninfo(vp, vtype, vsize, (void *)rdev);
-	puffs_newinfo_setvtype(pni, vtype);
+	puffs_newinfo_setvtype(pni, (enum vtype)vtype);
 	puffs_newinfo_setsize(pni, vsize);
 	/* LINTED: yea, it'll lose accuracy, but that's life */
 	puffs_newinfo_setrdev(pni, rdev);
@@ -740,7 +740,7 @@ p2k_node_lookup(struct puffs_usermount *
 
 	puffs_newinfo_setcookie(pni, p2n);
 	rump_pub_getvninfo(vp, vtype, vsize, (void *)rdev);
-	puffs_newinfo_setvtype(pni, vtype);
+	puffs_newinfo_setvtype(pni, (enum vtype)vtype);
 	puffs_newinfo_setsize(pni, vsize);
 	/* LINTED: yea, it'll lose accuracy, but that's life */
 	puffs_newinfo_setrdev(pni, rdev);



CVS commit: src/sys/netinet

2012-11-23 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Fri Nov 23 14:48:31 UTC 2012

Modified Files:
src/sys/netinet: tcp_vtw.h

Log Message:
Add RCS keyword. Avoid overflow in constant.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/netinet/tcp_vtw.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/netinet/tcp_vtw.h
diff -u src/sys/netinet/tcp_vtw.h:1.5 src/sys/netinet/tcp_vtw.h:1.6
--- src/sys/netinet/tcp_vtw.h:1.5	Tue Jun  7 22:51:32 2011
+++ src/sys/netinet/tcp_vtw.h	Fri Nov 23 14:48:31 2012
@@ -1,3 +1,4 @@
+/*	$NetBSD: tcp_vtw.h,v 1.6 2012/11/23 14:48:31 joerg Exp $	*/
 /*
  * Copyright (c) 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -186,7 +187,7 @@ fatp_full(fatp_t *fp) 
 {
 	fatp_t full;
 
-	full.inuse = ~0;
+	full.inuse = (1U  FATP_NTAGS) - 1U;
 
 	return (fp-inuse == full.inuse);
 }



CVS commit: src/usr.bin/systat

2012-11-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Nov 23 15:35:57 UTC 2012

Modified Files:
src/usr.bin/systat: bufcache.c

Log Message:
bufmem is unsigned.


To generate a diff of this commit:
cvs rdiff -u -r1.24 -r1.25 src/usr.bin/systat/bufcache.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/systat/bufcache.c
diff -u src/usr.bin/systat/bufcache.c:1.24 src/usr.bin/systat/bufcache.c:1.25
--- src/usr.bin/systat/bufcache.c:1.24	Fri Nov 23 01:44:38 2012
+++ src/usr.bin/systat/bufcache.c	Fri Nov 23 10:35:57 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: bufcache.c,v 1.24 2012/11/23 06:44:38 pgoyette Exp $	*/
+/*	$NetBSD: bufcache.c,v 1.25 2012/11/23 15:35:57 christos Exp $	*/
 
 /*-
  * Copyright (c) 1999 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include sys/cdefs.h
 #ifndef lint
-__RCSID($NetBSD: bufcache.c,v 1.24 2012/11/23 06:44:38 pgoyette Exp $);
+__RCSID($NetBSD: bufcache.c,v 1.25 2012/11/23 15:35:57 christos Exp $);
 #endif /* not lint */
 
 #include sys/param.h
@@ -134,7 +134,7 @@ showbufcache(void)
 		error(can't get \vm.bufmmem\: %s, strerror(errno));
 
 	mvwprintw(wnd, 0, 0,
-	   %*d metadata buffers using %*PRId64 kBytes of 
+	   %*d metadata buffers using %*PRIu64 kBytes of 
 	memory (%2.0f%%).,
 	pgwidth, nbuf, kbwidth, bufmem / 1024,
 	((bufmem * 100.0) + 0.5) / getpagesize() / uvmexp.npages);



CVS commit: [netbsd-6] src/sys/arch/sparc64

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:12:36 UTC 2012

Modified Files:
src/sys/arch/sparc64/include [netbsd-6]: cpu.h ctlreg.h psl.h
src/sys/arch/sparc64/sparc64 [netbsd-6]: clock.c cpu.c locore.s

Log Message:
Pull up following revision(s) (requested by macallan in ticket #695):
sys/arch/sparc64/include/cpu.h: revision 1.99
sys/arch/sparc64/sparc64/cpu.c: revision 1.103
sys/arch/sparc64/include/psl.h: revision 1.50
sys/arch/sparc64/sparc64/clock.c: revision 1.107
sys/arch/sparc64/include/ctlreg.h: revision 1.57
sys/arch/sparc64/sparc64/locore.s: revision 1.342
use system tick timer instead of %tick on UltraSPARC-III-ish CPUs
review  fixes by Takeshi Nakayama


To generate a diff of this commit:
cvs rdiff -u -r1.98 -r1.98.8.1 src/sys/arch/sparc64/include/cpu.h
cvs rdiff -u -r1.56 -r1.56.8.1 src/sys/arch/sparc64/include/ctlreg.h
cvs rdiff -u -r1.49 -r1.49.8.1 src/sys/arch/sparc64/include/psl.h
cvs rdiff -u -r1.106 -r1.106.8.1 src/sys/arch/sparc64/sparc64/clock.c
cvs rdiff -u -r1.101 -r1.101.8.1 src/sys/arch/sparc64/sparc64/cpu.c
cvs rdiff -u -r1.338.8.2 -r1.338.8.3 src/sys/arch/sparc64/sparc64/locore.s

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/include/cpu.h
diff -u src/sys/arch/sparc64/include/cpu.h:1.98 src/sys/arch/sparc64/include/cpu.h:1.98.8.1
--- src/sys/arch/sparc64/include/cpu.h:1.98	Sat Jul 30 19:29:12 2011
+++ src/sys/arch/sparc64/include/cpu.h	Fri Nov 23 16:12:35 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: cpu.h,v 1.98 2011/07/30 19:29:12 martin Exp $ */
+/*	$NetBSD: cpu.h,v 1.98.8.1 2012/11/23 16:12:35 riz Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -128,7 +128,8 @@ struct cpu_info {
 
 	/* %tick and cpu frequency information */
 	u_long			ci_tick_increment;
-	uint64_t		ci_cpu_clockrate[2];
+	uint64_t		ci_cpu_clockrate[2];	/* %tick */
+	uint64_t		ci_system_clockrate[2];	/* %stick */
 
 	/* Interrupts */
 	struct intrhand		*ci_intrpending[16];
@@ -351,10 +352,12 @@ void *	reserve_dumppages(void *);
 /* clock.c */
 struct timeval;
 int	tickintr(void *);	/* level 10/14 (tick) interrupt code */
+int	stickintr(void *);	/* system tick interrupt code */
 int	clockintr(void *);	/* level 10 (clock) interrupt code */
 int	statintr(void *);	/* level 14 (statclock) interrupt code */
 int	schedintr(void *);	/* level 10 (schedclock) interrupt code */
 void	tickintr_establish(int, int (*)(void *));
+void	stickintr_establish(int, int (*)(void *));
 /* locore.s */
 struct fpstate64;
 void	savefpstate(struct fpstate64 *);
@@ -372,6 +375,10 @@ struct frame *getfp(void);
 void	switchtoctx_us(int);
 void	switchtoctx_usiii(int);
 void	next_tick(long);
+void	next_stick(long);
+void	setstick(long);
+long	getstick(void);
+
 /* trap.c */
 void	cpu_vmspace_exec(struct lwp *, vaddr_t, vaddr_t);
 int	rwindow_save(struct lwp *);

Index: src/sys/arch/sparc64/include/ctlreg.h
diff -u src/sys/arch/sparc64/include/ctlreg.h:1.56 src/sys/arch/sparc64/include/ctlreg.h:1.56.8.1
--- src/sys/arch/sparc64/include/ctlreg.h:1.56	Sat Oct  8 08:49:07 2011
+++ src/sys/arch/sparc64/include/ctlreg.h	Fri Nov 23 16:12:36 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: ctlreg.h,v 1.56 2011/10/08 08:49:07 nakayama Exp $ */
+/*	$NetBSD: ctlreg.h,v 1.56.8.1 2012/11/23 16:12:36 riz Exp $ */
 
 /*
  * Copyright (c) 1996-2002 Eduardo Horvath
@@ -415,6 +415,8 @@
 #define	CLEAR_SOFTINT	%asr21	/* Clears these bits */
 #define	SOFTINT		%asr22	/* Reads the register */
 #define	TICK_CMPR	%asr23
+#define	STICK		%asr24
+#define	STICK_CMPR	%asr25
 
 #define	TICK_INT	0x01	/* level-14 clock tick */
 #define	SOFTINT1	(0x11)
@@ -432,6 +434,7 @@
 #define	SOFTINT13	(0x113)
 #define	SOFTINT14	(0x114)
 #define	SOFTINT15	(0x115)
+#define	STICK_INTR	(0x116)	/* system tick */
 
 /* Interrupt Dispatch -- usually reserved for cross-calls */
 #define	ASR_IDSR	0x48 /* Interrupt dispatch status reg */

Index: src/sys/arch/sparc64/include/psl.h
diff -u src/sys/arch/sparc64/include/psl.h:1.49 src/sys/arch/sparc64/include/psl.h:1.49.8.1
--- src/sys/arch/sparc64/include/psl.h:1.49	Tue Jul 12 07:51:34 2011
+++ src/sys/arch/sparc64/include/psl.h	Fri Nov 23 16:12:35 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: psl.h,v 1.49 2011/07/12 07:51:34 mrg Exp $ */
+/*	$NetBSD: psl.h,v 1.49.8.1 2012/11/23 16:12:35 riz Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -330,6 +330,7 @@ SPARC64_GETPR64_DEF(ver)			/* getver() *
 #define GETVER_CPU_IMPL()	((getver()  VER_IMPL)  VER_IMPL_SHIFT)
 #define GETVER_CPU_MANUF()	((getver()  VER_MANUF)  VER_MANUF_SHIFT)
 #define CPU_IS_SPITFIRE()	(GETVER_CPU_IMPL() == IMPL_SPITFIRE)
+#define CPU_IS_HUMMINGBIRD()	(GETVER_CPU_IMPL() == IMPL_HUMMINGBIRD)
 #define CPU_IS_USIIIi()		((GETVER_CPU_IMPL() == IMPL_JALAPENO) || \
  (GETVER_CPU_IMPL() == IMPL_SERRANO))
 #define CPU_IS_USIII_UP()	(GETVER_CPU_IMPL() = IMPL_CHEETAH)

Index: src/sys/arch/sparc64/sparc64/clock.c
diff -u 

CVS commit: [netbsd-6] src/sys/kern

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:16:56 UTC 2012

Modified Files:
src/sys/kern [netbsd-6]: kern_rndq.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #696):
sys/kern/kern_rndq.c: revision 1.6
Fix hardware RNGs -- accept their entropy estimates *rather than* using
timestamps to estimate the entropy of their input.  I'd accidentally
made it so no entropy was ever counted from them at all.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.3 -r1.1.2.4 src/sys/kern/kern_rndq.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/kern_rndq.c
diff -u src/sys/kern/kern_rndq.c:1.1.2.3 src/sys/kern/kern_rndq.c:1.1.2.4
--- src/sys/kern/kern_rndq.c:1.1.2.3	Wed Oct 17 21:27:12 2012
+++ src/sys/kern/kern_rndq.c	Fri Nov 23 16:16:56 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: kern_rndq.c,v 1.1.2.3 2012/10/17 21:27:12 riz Exp $	*/
+/*	$NetBSD: kern_rndq.c,v 1.1.2.4 2012/11/23 16:16:56 riz Exp $	*/
 
 /*-
  * Copyright (c) 1997-2011 The NetBSD Foundation, Inc.
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: kern_rndq.c,v 1.1.2.3 2012/10/17 21:27:12 riz Exp $);
+__KERNEL_RCSID(0, $NetBSD: kern_rndq.c,v 1.1.2.4 2012/11/23 16:16:56 riz Exp $);
 
 #include sys/param.h
 #include sys/ioctl.h
@@ -640,6 +640,11 @@ void
 rnd_add_data(krndsource_t *rs, const void *const data, uint32_t len,
 	 uint32_t entropy)
 {
+	/*
+	 * This interface is meant for feeding data which is,
+	 * itself, random.  Don't estimate entropy based on
+	 * timestamp, just directly add the data.
+	 */
 	rnd_add_data_ts(rs, data, len, entropy, rnd_counter());
 }
 
@@ -835,8 +840,6 @@ rnd_process_events(void *arg)
 		SIMPLEQ_REMOVE_HEAD(dq_samples, next);
 		source = sample-source;
 		entropy = sample-entropy;
-		if (source-flags  RND_FLAG_NO_ESTIMATE)
-			entropy = 0;
 
 		/*
 		 * Hardware generators are great but sometimes they



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:17:47 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
Tickets 695, 696


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.37 -r1.1.2.38 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.1
diff -u src/doc/CHANGES-6.1:1.1.2.37 src/doc/CHANGES-6.1:1.1.2.38
--- src/doc/CHANGES-6.1:1.1.2.37	Thu Nov 22 20:26:06 2012
+++ src/doc/CHANGES-6.1	Fri Nov 23 16:17:46 2012
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.1,v 1.1.2.37 2012/11/22 20:26:06 riz Exp $
+# $NetBSD: CHANGES-6.1,v 1.1.2.38 2012/11/23 16:17:46 riz Exp $
 
 A complete list of changes from the 6.0 release until the 6.1 release:
 
@@ -876,3 +876,19 @@ sys/uvm/uvm_object.h1.33
 	Improve UVM aobj locking, and fix a bug.
 	[rmind, ticket #694]
 
+sys/arch/sparc64/include/cpu.h			1.99
+sys/arch/sparc64/include/ctlreg.h		1.57
+sys/arch/sparc64/include/psl.h			1.50
+sys/arch/sparc64/sparc64/clock.c		1.107
+sys/arch/sparc64/sparc64/cpu.c			1.103
+sys/arch/sparc64/sparc64/locore.s		1.342
+
+	Improve time keeping on some UltraSPARC-IIIish systems.
+	[macallan, ticket #695]
+
+sys/kern/kern_rndq.c1.6
+
+	Fix hardware RNGs -- accept their entropy estimates *rather than* using
+	timestamps to estimate the entropy of their input.
+	[msaitoh, ticket #696]
+



CVS commit: [netbsd-6] src/sys/dev/pci

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:35:21 UTC 2012

Modified Files:
src/sys/dev/pci [netbsd-6]: if_wm.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #697):
sys/dev/pci/if_wm.c: revision 1.237
Fix a bug that PHY isn't set to low-power mode on PCH and PCH2.


To generate a diff of this commit:
cvs rdiff -u -r1.227.2.3 -r1.227.2.4 src/sys/dev/pci/if_wm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_wm.c
diff -u src/sys/dev/pci/if_wm.c:1.227.2.3 src/sys/dev/pci/if_wm.c:1.227.2.4
--- src/sys/dev/pci/if_wm.c:1.227.2.3	Mon Sep  3 19:09:41 2012
+++ src/sys/dev/pci/if_wm.c	Fri Nov 23 16:35:21 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_wm.c,v 1.227.2.3 2012/09/03 19:09:41 riz Exp $	*/
+/*	$NetBSD: if_wm.c,v 1.227.2.4 2012/11/23 16:35:21 riz Exp $	*/
 
 /*
  * Copyright (c) 2001, 2002, 2003, 2004 Wasabi Systems, Inc.
@@ -76,7 +76,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.227.2.3 2012/09/03 19:09:41 riz Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.227.2.4 2012/11/23 16:35:21 riz Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -4372,7 +4372,7 @@ wm_init(struct ifnet *ifp)
 
 	reg = CSR_READ(sc, WMREG_CTRL_EXT);
 	/* Enable PHY low-power state when MAC is at D3 w/o WoL */
-	if ((sc-sc_type == WM_T_PCH)  (sc-sc_type == WM_T_PCH2))
+	if ((sc-sc_type == WM_T_PCH) || (sc-sc_type == WM_T_PCH2))
 		CSR_WRITE(sc, WMREG_CTRL_EXT, reg | CTRL_EXT_PHYPDEN);
 
 	/* Initialize the transmit descriptor ring. */



CVS commit: [netbsd-6] src/sbin/init

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:37:22 UTC 2012

Modified Files:
src/sbin/init [netbsd-6]: init.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #698):
sbin/init/init.c: revision 1.105
Add missing free() in error path.


To generate a diff of this commit:
cvs rdiff -u -r1.102 -r1.102.4.1 src/sbin/init/init.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/init/init.c
diff -u src/sbin/init/init.c:1.102 src/sbin/init/init.c:1.102.4.1
--- src/sbin/init/init.c:1.102	Sun Aug 28 10:13:03 2011
+++ src/sbin/init/init.c	Fri Nov 23 16:37:21 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: init.c,v 1.102 2011/08/28 10:13:03 christos Exp $	*/
+/*	$NetBSD: init.c,v 1.102.4.1 2012/11/23 16:37:21 riz Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -42,7 +42,7 @@ __COPYRIGHT(@(#) Copyright (c) 1991, 19
 #if 0
 static char sccsid[] = @(#)init.c	8.2 (Berkeley) 4/28/95;
 #else
-__RCSID($NetBSD: init.c,v 1.102 2011/08/28 10:13:03 christos Exp $);
+__RCSID($NetBSD: init.c,v 1.102.4.1 2012/11/23 16:37:21 riz Exp $);
 #endif
 #endif /* not lint */
 
@@ -1097,8 +1097,10 @@ new_session(session_t *sprev, int sessio
 	sp-se_index = session_index;
 
 	(void)asprintf(sp-se_device, %s%s, _PATH_DEV, typ-ty_name);
-	if (!sp-se_device)
+	if (!sp-se_device) {
+		free(sp);
 		return NULL;
+	}
 
 	if (setupargv(sp, typ) == 0) {
 		free_session(sp);



CVS commit: [netbsd-6] src/sys/dev/isa

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:38:45 UTC 2012

Modified Files:
src/sys/dev/isa [netbsd-6]: itesio_isa.c itesio_isavar.h

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #699):
sys/dev/isa/itesio_isavar.h: revision 1.9
sys/dev/isa/itesio_isa.c: revision 1.24
Add support for ITE8720F by Nat Sloss. PR#47169.


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.23.8.1 src/sys/dev/isa/itesio_isa.c
cvs rdiff -u -r1.8 -r1.8.14.1 src/sys/dev/isa/itesio_isavar.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/isa/itesio_isa.c
diff -u src/sys/dev/isa/itesio_isa.c:1.23 src/sys/dev/isa/itesio_isa.c:1.23.8.1
--- src/sys/dev/isa/itesio_isa.c:1.23	Fri Jul 29 20:58:47 2011
+++ src/sys/dev/isa/itesio_isa.c	Fri Nov 23 16:38:45 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: itesio_isa.c,v 1.23 2011/07/29 20:58:47 jmcneill Exp $ */
+/*	$NetBSD: itesio_isa.c,v 1.23.8.1 2012/11/23 16:38:45 riz Exp $ */
 /*	Derived from $OpenBSD: it.c,v 1.19 2006/04/10 00:57:54 deraadt Exp $	*/
 
 /*
@@ -34,7 +34,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: itesio_isa.c,v 1.23 2011/07/29 20:58:47 jmcneill Exp $);
+__KERNEL_RCSID(0, $NetBSD: itesio_isa.c,v 1.23.8.1 2012/11/23 16:38:45 riz Exp $);
 
 #include sys/param.h
 #include sys/kernel.h
@@ -140,6 +140,7 @@ itesio_isa_match(device_t parent, cfdata
 	case ITESIO_ID8712:
 	case ITESIO_ID8716:
 	case ITESIO_ID8718:
+	case ITESIO_ID8720:
 	case ITESIO_ID8721:
 	case ITESIO_ID8726:
 		ia-ia_nio = 1;

Index: src/sys/dev/isa/itesio_isavar.h
diff -u src/sys/dev/isa/itesio_isavar.h:1.8 src/sys/dev/isa/itesio_isavar.h:1.8.14.1
--- src/sys/dev/isa/itesio_isavar.h:1.8	Fri Aug 13 19:28:26 2010
+++ src/sys/dev/isa/itesio_isavar.h	Fri Nov 23 16:38:45 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: itesio_isavar.h,v 1.8 2010/08/13 19:28:26 jakllsch Exp $	*/
+/*	$NetBSD: itesio_isavar.h,v 1.8.14.1 2012/11/23 16:38:45 riz Exp $	*/
 /*	$OpenBSD: itvar.h,v 1.2 2003/11/05 20:57:10 grange Exp $	*/
 
 /*
@@ -61,6 +61,7 @@
 #define ITESIO_ID8712	0x8712
 #define ITESIO_ID8716	0x8716
 #define ITESIO_ID8718	0x8718
+#define ITESIO_ID8720	0x8720
 #define ITESIO_ID8721	0x8721
 #define ITESIO_ID8726	0x8726
 



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:40:01 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
Tickets 697-699


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.38 -r1.1.2.39 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.1
diff -u src/doc/CHANGES-6.1:1.1.2.38 src/doc/CHANGES-6.1:1.1.2.39
--- src/doc/CHANGES-6.1:1.1.2.38	Fri Nov 23 16:17:46 2012
+++ src/doc/CHANGES-6.1	Fri Nov 23 16:40:01 2012
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.1,v 1.1.2.38 2012/11/23 16:17:46 riz Exp $
+# $NetBSD: CHANGES-6.1,v 1.1.2.39 2012/11/23 16:40:01 riz Exp $
 
 A complete list of changes from the 6.0 release until the 6.1 release:
 
@@ -892,3 +892,19 @@ sys/kern/kern_rndq.c1.6
 	timestamps to estimate the entropy of their input.
 	[msaitoh, ticket #696]
 
+sys/dev/pci/if_wm.c1.237
+
+	Fix a bug that PHY isn't set to low-power mode on PCH and PCH2.
+	[msaitoh, ticket #697]
+
+sbin/init/init.c1.105
+
+	Add missing free() in error path.
+	[msaitoh, ticket #698]
+
+sys/dev/isa/itesio_isa.c			1.24
+sys/dev/isa/itesio_isavar.h			1.9
+
+	Add support for ITE8720F. PR#47169.
+	[msaitoh, ticket #699]
+



CVS commit: [netbsd-6] src/sys/dev/usb

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:01:21 UTC 2012

Modified Files:
src/sys/dev/usb [netbsd-6]: if_urndis.c

Log Message:
Pull up following revision(s) (requested by joerg in ticket #700):
sys/dev/usb/if_urndis.c: revision 1.4
Don't match on idVendor=0x  idProduct=0x.
OpenBSD usb_lookup() might need this as a terminating entry,
but we don't at this point.
Repulsively enough, something that should be a uhidev(4),
ServerEngines SE USB Device, rev 1.10/0.01
has these ID numbers.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.3.2.1 src/sys/dev/usb/if_urndis.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/if_urndis.c
diff -u src/sys/dev/usb/if_urndis.c:1.3 src/sys/dev/usb/if_urndis.c:1.3.2.1
--- src/sys/dev/usb/if_urndis.c:1.3	Fri Dec 23 00:51:44 2011
+++ src/sys/dev/usb/if_urndis.c	Sat Nov 24 04:01:21 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_urndis.c,v 1.3 2011/12/23 00:51:44 jakllsch Exp $ */
+/*	$NetBSD: if_urndis.c,v 1.3.2.1 2012/11/24 04:01:21 riz Exp $ */
 /*	$OpenBSD: if_urndis.c,v 1.31 2011/07/03 15:47:17 matthew Exp $ */
 
 /*
@@ -21,7 +21,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_urndis.c,v 1.3 2011/12/23 00:51:44 jakllsch Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_urndis.c,v 1.3.2.1 2012/11/24 04:01:21 riz Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -124,7 +124,6 @@ CFATTACH_DECL_NEW(urndis, sizeof(struct 
 static const struct usb_devno urndis_devs[] = {
 	{ USB_VENDOR_HTC,	USB_PRODUCT_HTC_ANDROID },
 	{ USB_VENDOR_SAMSUNG,	USB_PRODUCT_SAMSUNG_ANDROID2 },
-	{ 0, 0 }
 };
 
 static usbd_status



CVS commit: [netbsd-6-0] src/sys/dev/usb

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:01:30 UTC 2012

Modified Files:
src/sys/dev/usb [netbsd-6-0]: if_urndis.c

Log Message:
Pull up following revision(s) (requested by joerg in ticket #700):
sys/dev/usb/if_urndis.c: revision 1.4
Don't match on idVendor=0x  idProduct=0x.
OpenBSD usb_lookup() might need this as a terminating entry,
but we don't at this point.
Repulsively enough, something that should be a uhidev(4),
ServerEngines SE USB Device, rev 1.10/0.01
has these ID numbers.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.3.6.1 src/sys/dev/usb/if_urndis.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/if_urndis.c
diff -u src/sys/dev/usb/if_urndis.c:1.3 src/sys/dev/usb/if_urndis.c:1.3.6.1
--- src/sys/dev/usb/if_urndis.c:1.3	Fri Dec 23 00:51:44 2011
+++ src/sys/dev/usb/if_urndis.c	Sat Nov 24 04:01:30 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_urndis.c,v 1.3 2011/12/23 00:51:44 jakllsch Exp $ */
+/*	$NetBSD: if_urndis.c,v 1.3.6.1 2012/11/24 04:01:30 riz Exp $ */
 /*	$OpenBSD: if_urndis.c,v 1.31 2011/07/03 15:47:17 matthew Exp $ */
 
 /*
@@ -21,7 +21,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_urndis.c,v 1.3 2011/12/23 00:51:44 jakllsch Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_urndis.c,v 1.3.6.1 2012/11/24 04:01:30 riz Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -124,7 +124,6 @@ CFATTACH_DECL_NEW(urndis, sizeof(struct 
 static const struct usb_devno urndis_devs[] = {
 	{ USB_VENDOR_HTC,	USB_PRODUCT_HTC_ANDROID },
 	{ USB_VENDOR_SAMSUNG,	USB_PRODUCT_SAMSUNG_ANDROID2 },
-	{ 0, 0 }
 };
 
 static usbd_status



CVS commit: [netbsd-6-0] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:01:43 UTC 2012

Modified Files:
src/doc [netbsd-6-0]: CHANGES-6.0.1

Log Message:
Ticket 700


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.19 -r1.1.2.20 src/doc/CHANGES-6.0.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.0.1
diff -u src/doc/CHANGES-6.0.1:1.1.2.19 src/doc/CHANGES-6.0.1:1.1.2.20
--- src/doc/CHANGES-6.0.1:1.1.2.19	Thu Nov 22 18:51:29 2012
+++ src/doc/CHANGES-6.0.1	Sat Nov 24 04:01:43 2012
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.0.1,v 1.1.2.19 2012/11/22 18:51:29 riz Exp $
+# $NetBSD: CHANGES-6.0.1,v 1.1.2.20 2012/11/24 04:01:43 riz Exp $
 
 A complete list of changes from the NetBSD 6.0 release to the NetBSD 6.0.1
 release:
@@ -164,3 +164,9 @@ sys/kern/vfs_vnops.c1.186
 	It is impossible to resolve these races in vn_lock().
 	[hannken, ticket #692]
 
+sys/dev/usb/if_urndis.c1.4
+
+	Don't match on idVendor=0x  idProduct=0x. Fixes the
+	keyboard on a number of HP and possibly other vendors' machines.
+	[joerg, ticket #700]
+



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:02:00 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
ticket 700


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.39 -r1.1.2.40 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.1
diff -u src/doc/CHANGES-6.1:1.1.2.39 src/doc/CHANGES-6.1:1.1.2.40
--- src/doc/CHANGES-6.1:1.1.2.39	Fri Nov 23 16:40:01 2012
+++ src/doc/CHANGES-6.1	Sat Nov 24 04:02:00 2012
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.1,v 1.1.2.39 2012/11/23 16:40:01 riz Exp $
+# $NetBSD: CHANGES-6.1,v 1.1.2.40 2012/11/24 04:02:00 riz Exp $
 
 A complete list of changes from the 6.0 release until the 6.1 release:
 
@@ -908,3 +908,9 @@ sys/dev/isa/itesio_isavar.h			1.9
 	Add support for ITE8720F. PR#47169.
 	[msaitoh, ticket #699]
 
+sys/dev/usb/if_urndis.c1.4
+
+	Don't match on idVendor=0x  idProduct=0x. Fixes the
+	keyboard on a number of HP and possibly other vendors' machines.
+	[joerg, ticket #700]
+



CVS commit: [netbsd-6] src/lib/libc/arch/arm/sys

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:23:27 UTC 2012

Modified Files:
src/lib/libc/arch/arm/sys [netbsd-6]: __aeabi_read_tp.S

Log Message:
Pull up following revision(s) (requested by matt in ticket #701):
lib/libc/arch/arm/sys/__aeabi_read_tp.S: revision 1.3
Add $NetBSD$ tag.  Use ip to save r1 instead of the stack.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.2.2.1 src/lib/libc/arch/arm/sys/__aeabi_read_tp.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/arch/arm/sys/__aeabi_read_tp.S
diff -u src/lib/libc/arch/arm/sys/__aeabi_read_tp.S:1.2 src/lib/libc/arch/arm/sys/__aeabi_read_tp.S:1.2.2.1
--- src/lib/libc/arch/arm/sys/__aeabi_read_tp.S:1.2	Tue Feb 14 17:32:43 2012
+++ src/lib/libc/arch/arm/sys/__aeabi_read_tp.S	Sat Nov 24 04:23:27 2012
@@ -1,13 +1,20 @@
+/* $NetBSD: __aeabi_read_tp.S,v 1.2.2.1 2012/11/24 04:23:27 riz Exp $ */
+
 #include SYS.h
 
+/*
+ * Implementations of this function should corrupt only the result register
+ * (r0) and the non-parameter integer core registers allowed to be corrupted
+ * by the [AAPCS] (ip, lr, and CPSR).
+ */
 ENTRY(__aeabi_read_tp)
-	mrc p15, 0, r0, c13, c0, 3
+	mrc	p15, 0, r0, c13, c0, 3
 #ifndef _ARM_ARCH_6
-	cmp r0, #0			/* was it zero? */
+	cmp	r0, #0			/* was it zero? */
 	RETc(ne)			/* return it's not zero */
-	push {r1}			/* syscall zeroes r1 */
+	mov	ip, r1			/* syscall zeroes r1 */
 	SYSTRAP(_lwp_getprivate)	/* can't fail */
-	pop {r1}			/* restore r1 */
+	mov	r1, ip			/* restore r1 */
 #endif
 	RET
 _END(__aeabi_read_tp)



CVS commit: [netbsd-6] src

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:34:44 UTC 2012

Modified Files:
src/sys/net/npf [netbsd-6]: npf.c npf.h npf_ctl.c npf_impl.h
npf_state_tcp.c npf_tableset.c
src/usr.sbin/npf/npfctl [netbsd-6]: npf_disassemble.c npfctl.8 npfctl.c
npfctl.h
src/usr.sbin/npf/npftest/libnpftest [netbsd-6]: npf_table_test.c

Log Message:
Pull up following revision(s) (requested by rmind in ticket #702):
sys/net/npf/npf_tableset.c: revision 1.15
usr.sbin/npf/npfctl/npfctl.h: revision 1.21
usr.sbin/npf/npftest/libnpftest/npf_table_test.c: revision 1.6
usr.sbin/npf/npfctl/npf_disassemble.c: revision 1.10
sys/net/npf/npf_state_tcp.c: revision 1.11
sys/net/npf/npf_impl.h: revision 1.24
sys/net/npf/npf.h: revision 1.22
sys/net/npf/npf_ctl.c: revision 1.19
sys/net/npf/npf.c: revision 1.14
usr.sbin/npf/npfctl/npfctl.8: revision 1.10
usr.sbin/npf/npfctl/npfctl.c: revision 1.21
npf_tcp_inwindow: inspect the sequence numbers even if the packet contains no
data, fixing up only the RST to the initial SYN.  This makes off-path attacks
more difficult.  For the reference, see quot;Reflection Scan: an Off-Path 
Attack
on TCPquot; by Jan Wrobel.
Implement NPF table listing and preservation of entries on reload.
Bump the version.
npfctl(8): mention table listing.


To generate a diff of this commit:
cvs rdiff -u -r1.7.2.5 -r1.7.2.6 src/sys/net/npf/npf.c
cvs rdiff -u -r1.14.2.7 -r1.14.2.8 src/sys/net/npf/npf.h
cvs rdiff -u -r1.12.2.5 -r1.12.2.6 src/sys/net/npf/npf_ctl.c
cvs rdiff -u -r1.10.2.9 -r1.10.2.10 src/sys/net/npf/npf_impl.h
cvs rdiff -u -r1.3.2.5 -r1.3.2.6 src/sys/net/npf/npf_state_tcp.c
cvs rdiff -u -r1.9.2.5 -r1.9.2.6 src/sys/net/npf/npf_tableset.c
cvs rdiff -u -r1.3.2.7 -r1.3.2.8 src/usr.sbin/npf/npfctl/npf_disassemble.c
cvs rdiff -u -r1.6.6.2 -r1.6.6.3 src/usr.sbin/npf/npfctl/npfctl.8
cvs rdiff -u -r1.10.2.7 -r1.10.2.8 src/usr.sbin/npf/npfctl/npfctl.c
cvs rdiff -u -r1.11.2.7 -r1.11.2.8 src/usr.sbin/npf/npfctl/npfctl.h
cvs rdiff -u -r1.2.2.6 -r1.2.2.7 \
src/usr.sbin/npf/npftest/libnpftest/npf_table_test.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/npf/npf.h
diff -u src/sys/net/npf/npf.h:1.14.2.7 src/sys/net/npf/npf.h:1.14.2.8
--- src/sys/net/npf/npf.h:1.14.2.7	Sun Nov 18 22:38:26 2012
+++ src/sys/net/npf/npf.h	Sat Nov 24 04:34:42 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: npf.h,v 1.14.2.7 2012/11/18 22:38:26 riz Exp $	*/
+/*	$NetBSD: npf.h,v 1.14.2.8 2012/11/24 04:34:42 riz Exp $	*/
 
 /*-
  * Copyright (c) 2009-2012 The NetBSD Foundation, Inc.
@@ -45,7 +45,7 @@
 #include netinet/in_systm.h
 #include netinet/in.h
 
-#define	NPF_VERSION		6
+#define	NPF_VERSION		7
 
 /*
  * Public declarations and definitions.
@@ -211,15 +211,29 @@ bool		npf_autounload_p(void);
  * IOCTL structures.
  */
 
+#define	NPF_IOCTL_TBLENT_LOOKUP		0
 #define	NPF_IOCTL_TBLENT_ADD		1
 #define	NPF_IOCTL_TBLENT_REM		2
+#define	NPF_IOCTL_TBLENT_LIST		3
+
+typedef struct npf_ioctl_ent {
+	int			alen;
+	npf_addr_t		addr;
+	npf_netmask_t		mask;
+} npf_ioctl_ent_t;
+
+typedef struct npf_ioctl_buf {
+	void *			buf;
+	size_t			len;
+} npf_ioctl_buf_t;
 
 typedef struct npf_ioctl_table {
 	int			nct_action;
 	u_int			nct_tid;
-	int			nct_alen;
-	npf_addr_t		nct_addr;
-	npf_netmask_t		nct_mask;
+	union {
+		npf_ioctl_ent_t	ent;
+		npf_ioctl_buf_t	buf;
+	} nct_data;
 } npf_ioctl_table_t;
 
 typedef enum {

Index: src/sys/net/npf/npf_ctl.c
diff -u src/sys/net/npf/npf_ctl.c:1.12.2.5 src/sys/net/npf/npf_ctl.c:1.12.2.6
--- src/sys/net/npf/npf_ctl.c:1.12.2.5	Sun Nov 18 22:38:26 2012
+++ src/sys/net/npf/npf_ctl.c	Sat Nov 24 04:34:42 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: npf_ctl.c,v 1.12.2.5 2012/11/18 22:38:26 riz Exp $	*/
+/*	$NetBSD: npf_ctl.c,v 

CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:36:38 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
tickets 701, 702


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.40 -r1.1.2.41 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.1
diff -u src/doc/CHANGES-6.1:1.1.2.40 src/doc/CHANGES-6.1:1.1.2.41
--- src/doc/CHANGES-6.1:1.1.2.40	Sat Nov 24 04:02:00 2012
+++ src/doc/CHANGES-6.1	Sat Nov 24 04:36:38 2012
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.1,v 1.1.2.40 2012/11/24 04:02:00 riz Exp $
+# $NetBSD: CHANGES-6.1,v 1.1.2.41 2012/11/24 04:36:38 riz Exp $
 
 A complete list of changes from the 6.0 release until the 6.1 release:
 
@@ -914,3 +914,24 @@ sys/dev/usb/if_urndis.c1.4
 	keyboard on a number of HP and possibly other vendors' machines.
 	[joerg, ticket #700]
 
+lib/libc/arch/arm/sys/__aeabi_read_tp.S		1.3
+
+	Add $NetBSD: CHANGES-6.1,v 1.1.2.41 2012/11/24 04:36:38 riz Exp $ tag.  Use ip to save r1 instead of the stack.
+	[matt, ticket #701]
+
+sys/net/npf/npf.c1.14
+sys/net/npf/npf.h1.22
+sys/net/npf/npf_ctl.c1.19
+sys/net/npf/npf_impl.h1.24
+sys/net/npf/npf_state_tcp.c			1.11
+sys/net/npf/npf_tableset.c			1.15
+usr.sbin/npf/npfctl/npf_disassemble.c		1.10
+usr.sbin/npf/npfctl/npfctl.8			1.10
+usr.sbin/npf/npfctl/npfctl.c			1.21
+usr.sbin/npf/npfctl/npfctl.h			1.21
+usr.sbin/npf/npftest/libnpftest/npf_table_test.c 1.6
+
+	Protect better against off-path attacks.  Implement NPF table
+	listing, and preservation of entries on reload.
+	[rmind, ticket #702]
+



CVS commit: src/lib/libc/arch/powerpc64/gen

2012-11-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sat Nov 24 07:16:05 UTC 2012

Modified Files:
src/lib/libc/arch/powerpc64/gen: syncicache.c

Log Message:
Use __arraycount(), and cast to u_int.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/lib/libc/arch/powerpc64/gen/syncicache.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/arch/powerpc64/gen/syncicache.c
diff -u src/lib/libc/arch/powerpc64/gen/syncicache.c:1.1 src/lib/libc/arch/powerpc64/gen/syncicache.c:1.2
--- src/lib/libc/arch/powerpc64/gen/syncicache.c:1.1	Sat Jul  1 12:37:20 2006
+++ src/lib/libc/arch/powerpc64/gen/syncicache.c	Sat Nov 24 02:16:04 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: syncicache.c,v 1.1 2006/07/01 16:37:20 ross Exp $	*/
+/*	$NetBSD: syncicache.c,v 1.2 2012/11/24 07:16:04 christos Exp $	*/
 
 /*
  * Copyright (C) 1995-1997, 1999 Wolfgang Solfrank.
@@ -74,17 +74,16 @@ __getcachelinesize(void)
 	if (_cachelinesize)
 		return _cachelinesize;
 
-	if (sysctl(cacheinfomib, sizeof(cacheinfomib) / sizeof(cacheinfomib[0]),
-		_cache_info, clen, NULL, 0) == 0) {
+	if (sysctl(cacheinfomib, (u_int)__arraycount(cacheinfomib),
+	_cache_info, clen, NULL, 0) == 0) {
 		_cachelinesize = _cache_info.dcache_line_size;
 		return _cachelinesize;
 	}
 
 	/* Try older deprecated sysctl */
 	clen = sizeof(_cachelinesize);
-	if (sysctl(cachemib, sizeof(cachemib) / sizeof(cachemib[0]),
-		   _cachelinesize, clen, NULL, 0)  0
-	|| !_cachelinesize)
+	if (sysctl(cachemib, (u_int)__arraycount(cachemib),
+	_cachelinesize, clen, NULL, 0)  0 || !_cachelinesize)
 		abort();
 
 	_cache_info.dcache_size = _cachelinesize;



CVS commit: src/tests/lib/libc/c063

2012-11-23 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Fri Nov 23 08:24:20 UTC 2012

Modified Files:
src/tests/lib/libc/c063: t_o_search.c

Log Message:
Split the test cases where root/non-root makes a difference in two and mark
them apropriately. Exact permission semantics are still under discussion,
this will have to be cleaned up once that discussion is settled.
For now, one test cases fails.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/tests/lib/libc/c063/t_o_search.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src

2012-11-23 Thread Nicolas Joly
Module Name:src
Committed By:   njoly
Date:   Fri Nov 23 08:36:48 UTC 2012

Modified Files:
src/distrib/sets/lists/tests: mi
src/etc/mtree: NetBSD.dist.tests

Log Message:
Adjust for usr/tests/lib/libc/c063 debug entries.


To generate a diff of this commit:
cvs rdiff -u -r1.508 -r1.509 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.89 -r1.90 src/etc/mtree/NetBSD.dist.tests

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libp2k

2012-11-23 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Fri Nov 23 14:27:14 UTC 2012

Modified Files:
src/lib/libp2k: p2k.c

Log Message:
Explicitly cast enum type.


To generate a diff of this commit:
cvs rdiff -u -r1.59 -r1.60 src/lib/libp2k/p2k.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/netinet

2012-11-23 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Fri Nov 23 14:48:31 UTC 2012

Modified Files:
src/sys/netinet: tcp_vtw.h

Log Message:
Add RCS keyword. Avoid overflow in constant.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/netinet/tcp_vtw.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/systat

2012-11-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Nov 23 15:35:57 UTC 2012

Modified Files:
src/usr.bin/systat: bufcache.c

Log Message:
bufmem is unsigned.


To generate a diff of this commit:
cvs rdiff -u -r1.24 -r1.25 src/usr.bin/systat/bufcache.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/sys/arch/sparc64

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:12:36 UTC 2012

Modified Files:
src/sys/arch/sparc64/include [netbsd-6]: cpu.h ctlreg.h psl.h
src/sys/arch/sparc64/sparc64 [netbsd-6]: clock.c cpu.c locore.s

Log Message:
Pull up following revision(s) (requested by macallan in ticket #695):
sys/arch/sparc64/include/cpu.h: revision 1.99
sys/arch/sparc64/sparc64/cpu.c: revision 1.103
sys/arch/sparc64/include/psl.h: revision 1.50
sys/arch/sparc64/sparc64/clock.c: revision 1.107
sys/arch/sparc64/include/ctlreg.h: revision 1.57
sys/arch/sparc64/sparc64/locore.s: revision 1.342
use system tick timer instead of %tick on UltraSPARC-III-ish CPUs
review  fixes by Takeshi Nakayama


To generate a diff of this commit:
cvs rdiff -u -r1.98 -r1.98.8.1 src/sys/arch/sparc64/include/cpu.h
cvs rdiff -u -r1.56 -r1.56.8.1 src/sys/arch/sparc64/include/ctlreg.h
cvs rdiff -u -r1.49 -r1.49.8.1 src/sys/arch/sparc64/include/psl.h
cvs rdiff -u -r1.106 -r1.106.8.1 src/sys/arch/sparc64/sparc64/clock.c
cvs rdiff -u -r1.101 -r1.101.8.1 src/sys/arch/sparc64/sparc64/cpu.c
cvs rdiff -u -r1.338.8.2 -r1.338.8.3 src/sys/arch/sparc64/sparc64/locore.s

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/sys/kern

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:16:56 UTC 2012

Modified Files:
src/sys/kern [netbsd-6]: kern_rndq.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #696):
sys/kern/kern_rndq.c: revision 1.6
Fix hardware RNGs -- accept their entropy estimates *rather than* using
timestamps to estimate the entropy of their input.  I'd accidentally
made it so no entropy was ever counted from them at all.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.3 -r1.1.2.4 src/sys/kern/kern_rndq.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:17:47 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
Tickets 695, 696


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.37 -r1.1.2.38 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/sys/dev/pci

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:35:21 UTC 2012

Modified Files:
src/sys/dev/pci [netbsd-6]: if_wm.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #697):
sys/dev/pci/if_wm.c: revision 1.237
Fix a bug that PHY isn't set to low-power mode on PCH and PCH2.


To generate a diff of this commit:
cvs rdiff -u -r1.227.2.3 -r1.227.2.4 src/sys/dev/pci/if_wm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/sbin/init

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:37:22 UTC 2012

Modified Files:
src/sbin/init [netbsd-6]: init.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #698):
sbin/init/init.c: revision 1.105
Add missing free() in error path.


To generate a diff of this commit:
cvs rdiff -u -r1.102 -r1.102.4.1 src/sbin/init/init.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/sys/dev/isa

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:38:45 UTC 2012

Modified Files:
src/sys/dev/isa [netbsd-6]: itesio_isa.c itesio_isavar.h

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #699):
sys/dev/isa/itesio_isavar.h: revision 1.9
sys/dev/isa/itesio_isa.c: revision 1.24
Add support for ITE8720F by Nat Sloss. PR#47169.


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.23.8.1 src/sys/dev/isa/itesio_isa.c
cvs rdiff -u -r1.8 -r1.8.14.1 src/sys/dev/isa/itesio_isavar.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Nov 23 16:40:01 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
Tickets 697-699


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.38 -r1.1.2.39 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/sys/dev/usb

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:01:21 UTC 2012

Modified Files:
src/sys/dev/usb [netbsd-6]: if_urndis.c

Log Message:
Pull up following revision(s) (requested by joerg in ticket #700):
sys/dev/usb/if_urndis.c: revision 1.4
Don't match on idVendor=0x  idProduct=0x.
OpenBSD usb_lookup() might need this as a terminating entry,
but we don't at this point.
Repulsively enough, something that should be a uhidev(4),
ServerEngines SE USB Device, rev 1.10/0.01
has these ID numbers.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.3.2.1 src/sys/dev/usb/if_urndis.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6-0] src/sys/dev/usb

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:01:30 UTC 2012

Modified Files:
src/sys/dev/usb [netbsd-6-0]: if_urndis.c

Log Message:
Pull up following revision(s) (requested by joerg in ticket #700):
sys/dev/usb/if_urndis.c: revision 1.4
Don't match on idVendor=0x  idProduct=0x.
OpenBSD usb_lookup() might need this as a terminating entry,
but we don't at this point.
Repulsively enough, something that should be a uhidev(4),
ServerEngines SE USB Device, rev 1.10/0.01
has these ID numbers.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.3.6.1 src/sys/dev/usb/if_urndis.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6-0] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:01:43 UTC 2012

Modified Files:
src/doc [netbsd-6-0]: CHANGES-6.0.1

Log Message:
Ticket 700


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.19 -r1.1.2.20 src/doc/CHANGES-6.0.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:02:00 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
ticket 700


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.39 -r1.1.2.40 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/lib/libc/arch/arm/sys

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:23:27 UTC 2012

Modified Files:
src/lib/libc/arch/arm/sys [netbsd-6]: __aeabi_read_tp.S

Log Message:
Pull up following revision(s) (requested by matt in ticket #701):
lib/libc/arch/arm/sys/__aeabi_read_tp.S: revision 1.3
Add $NetBSD$ tag.  Use ip to save r1 instead of the stack.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.2.2.1 src/lib/libc/arch/arm/sys/__aeabi_read_tp.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:34:44 UTC 2012

Modified Files:
src/sys/net/npf [netbsd-6]: npf.c npf.h npf_ctl.c npf_impl.h
npf_state_tcp.c npf_tableset.c
src/usr.sbin/npf/npfctl [netbsd-6]: npf_disassemble.c npfctl.8 npfctl.c
npfctl.h
src/usr.sbin/npf/npftest/libnpftest [netbsd-6]: npf_table_test.c

Log Message:
Pull up following revision(s) (requested by rmind in ticket #702):
sys/net/npf/npf_tableset.c: revision 1.15
usr.sbin/npf/npfctl/npfctl.h: revision 1.21
usr.sbin/npf/npftest/libnpftest/npf_table_test.c: revision 1.6
usr.sbin/npf/npfctl/npf_disassemble.c: revision 1.10
sys/net/npf/npf_state_tcp.c: revision 1.11
sys/net/npf/npf_impl.h: revision 1.24
sys/net/npf/npf.h: revision 1.22
sys/net/npf/npf_ctl.c: revision 1.19
sys/net/npf/npf.c: revision 1.14
usr.sbin/npf/npfctl/npfctl.8: revision 1.10
usr.sbin/npf/npfctl/npfctl.c: revision 1.21
npf_tcp_inwindow: inspect the sequence numbers even if the packet contains no
data, fixing up only the RST to the initial SYN.  This makes off-path attacks
more difficult.  For the reference, see quot;Reflection Scan: an Off-Path 
Attack
on TCPquot; by Jan Wrobel.
Implement NPF table listing and preservation of entries on reload.
Bump the version.
npfctl(8): mention table listing.


To generate a diff of this commit:
cvs rdiff -u -r1.7.2.5 -r1.7.2.6 src/sys/net/npf/npf.c
cvs rdiff -u -r1.14.2.7 -r1.14.2.8 src/sys/net/npf/npf.h
cvs rdiff -u -r1.12.2.5 -r1.12.2.6 src/sys/net/npf/npf_ctl.c
cvs rdiff -u -r1.10.2.9 -r1.10.2.10 src/sys/net/npf/npf_impl.h
cvs rdiff -u -r1.3.2.5 -r1.3.2.6 src/sys/net/npf/npf_state_tcp.c
cvs rdiff -u -r1.9.2.5 -r1.9.2.6 src/sys/net/npf/npf_tableset.c
cvs rdiff -u -r1.3.2.7 -r1.3.2.8 src/usr.sbin/npf/npfctl/npf_disassemble.c
cvs rdiff -u -r1.6.6.2 -r1.6.6.3 src/usr.sbin/npf/npfctl/npfctl.8
cvs rdiff -u -r1.10.2.7 -r1.10.2.8 src/usr.sbin/npf/npfctl/npfctl.c
cvs rdiff -u -r1.11.2.7 -r1.11.2.8 src/usr.sbin/npf/npfctl/npfctl.h
cvs rdiff -u -r1.2.2.6 -r1.2.2.7 \
src/usr.sbin/npf/npftest/libnpftest/npf_table_test.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-6] src/doc

2012-11-23 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Sat Nov 24 04:36:38 UTC 2012

Modified Files:
src/doc [netbsd-6]: CHANGES-6.1

Log Message:
tickets 701, 702


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.40 -r1.1.2.41 src/doc/CHANGES-6.1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libc/arch/powerpc64/gen

2012-11-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sat Nov 24 07:16:05 UTC 2012

Modified Files:
src/lib/libc/arch/powerpc64/gen: syncicache.c

Log Message:
Use __arraycount(), and cast to u_int.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/lib/libc/arch/powerpc64/gen/syncicache.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Index: src/sys/net/npf/npf.c
diff -u src/sys/net/npf/npf.c:1.7.2.5 src/sys/net/npf/npf.c:1.7.2.6
--- src/sys/net/npf/npf.c:1.7.2.5	Mon Nov 19 09:44:42 2012
+++ src/sys/net/npf/npf.c	Sat Nov 24 04:34:42 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: npf.c,v 1.7.2.5 2012/11/19 09:44:42 msaitoh Exp $	*/
+/*	$NetBSD: npf.c,v 1.7.2.6 2012/11/24 04:34:42 riz Exp $	*/
 
 /*-
  * Copyright (c) 2009-2012 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: npf.c,v 1.7.2.5 2012/11/19 09:44:42 msaitoh Exp $);
+__KERNEL_RCSID(0, $NetBSD: npf.c,v 1.7.2.6 2012/11/24 04:34:42 riz Exp $);
 
 #include sys/param.h
 #include sys/types.h
@@ -303,7 +303,9 @@ npf_reload(prop_dictionary_t dict, npf_r
 	rw_enter(npf_lock, RW_WRITER);
 	onc = atomic_swap_ptr(npf_core, nc);
 	if (onc) {
-		/* Reload only necessary NAT policies. */
+		/* Reload only the static tables. */
+		npf_tableset_reload(tset, onc-n_tables);
+		/* Reload only the necessary NAT policies. */
 		npf_ruleset_natreload(nset, onc-n_nat_rules);
 	}
 	/* Unlock.  Everything goes live now. */
